==> ckan-2.8.5.tar.gz: ckan-2.8.5/ckan/public/base/i18n/pt_PT.js <==
{
  "": {
    "domain": "ckan", 
    "lang": "pt_PT", 
    "plural-forms": "nplurals=2; plural=(n != 1);"
  }, 
  "%(color)s shirt": [
    "%(color)s shirts", 
    "", 
    ""
  ], 
  "%(num)d item": [
    "%(num)d items", 
    "%(num)d item", 
    "%(num)d itens"
  ], 
  "%(num)d missing translation": [
    "%(num)d missing translations", 
    "", 
    ""
  ], 
  "Add Filter": [
    null, 
    "Adicionar Filtro"
  ], 
  "An Error Occurred": [
    null, 
    "Ocorreu Um Erro"
  ], 
  "Are you sure you want to perform this action?": [
    null, 
    "Tem a certeza que deseja realizar esta ação?"
  ], 
  "Cancel": [
    null, 
    "Cancelar"
  ], 
  "Confirm": [
    null, 
    "Confirmar"
  ], 
  "Could not load view": [
    null, 
    "Não foi possível carregar a vista"
  ], 
  "Edit": [
    null, 
    "Editar"
  ], 
  "Failed to load data API information": [
    null, 
    "Falha no carregamento da informação dos dados API"
  ], 
  "File": [
    null, 
    "Ficheiro"
  ], 
  "Filters": [
    null, 
    "Filtros"
  ], 
  "Follow": [
    null, 
    "Seguir"
  ], 
  "Graph": [
    null, 
    "Gráfico"
  ], 
  "Grid": [
    null, 
    "Grelha"
  ], 
  "Hide": [
    null, 
    "Ocultar"
  ], 
  "Image": [
    null, 
    "Imagem"
  ], 
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters", 
    "", 
    ""
  ], 
  "Link": [
    null, 
    "Hiperligação"
  ], 
  "Link to a URL on the internet (you can also link to an API)": [
    null, 
    "Link para um URL na internet ( pode também ligar-se com API)"
  ], 
  "Loading...": [
    null, 
    "A carregar ..."
  ], 
  "Map": [
    null, 
    "Mapa"
  ], 
  "No matches found": [
    null, 
    "Não foram encontradas correspondências"
  ], 
  "Please Confirm Action": [
    null, 
    "Por favor, Confirme a Ação"
  ], 
  "Remove": [
    null, 
    "Remover"
  ], 
  "Resource uploaded": [
    null, 
    "Recurso enviado"
  ], 
  "Save order": [
    null, 
    "Guardar ordenação"
  ], 
  "Saving...": [
    null, 
    "A guardar ..."
  ], 
  "Select a field": [
    null, 
    "Selecione um campo"
  ], 
  "Show more": [
    null, 
    "Mostrar mais"
  ], 
  "Start typing…": [
    null, 
    "Comece a escrever ..."
  ], 
  "There are unsaved modifications to this form": [
    null, 
    "Existem modificações que não estão a ser guardadas"
  ], 
  "There is no API data to load for this resource": [
    null, 
    "Não há dados API para carregar neste recurso"
  ], 
  "URL": [
    null, 
    "URL"
  ], 
  "Unable to authenticate upload": [
    null, 
    "Não é possivel autenticar o envio"
  ], 
  "Unable to get data for uploaded file": [
    null, 
    "Não foi possivel obter dados a partir do ficheiro enviado"
  ], 
  "Unable to upload file": [
    null, 
    "Não é possivel enviar o ficheiro"
  ], 
  "Unfollow": [
    null, 
    "Não Seguir"
  ], 
  "Upload": [
    null, 
    "Enviar"
  ], 
  "Upload a file": [
    null, 
    "Enviar um ficheiro"
  ], 
  "Upload a file on your computer": [
    null, 
    "Envie um ficheiro no seu computador"
  ], 
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null, 
    "Está a enviar um ficheiro. Tem a certeza de que deseja sair e parar o envio?"
  ], 
  "bar": [
    "bars", 
    "", 
    ""
  ], 
  "error loading view": [
    null, 
    "erro a carregar a vista"
  ], 
  "hello %(name)s!": [
    null, 
    "olá %(name)s!"
  ], 
  "no %(attr)s translation": [
    "no %(attr)s translations", 
    "", 
    ""
  ], 
  "no translation": [
    "no translations", 
    "sem tradução", 
    "sem traduções"
  ]
}

==> ckan-2.9.9.tar.gz: ckan-2.9.9/ckan/public/base/i18n/pt_PT.js <==
{
  "": {
    "domain": "ckan",
    "lang": "pt_PT",
    "plural-forms": "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;"
  },
  "Add Filter": [
    null,
    "Adicionar Filtro"
  ],
  "An Error Occurred": [
    null,
    "Ocorreu Um Erro"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Tem a certeza que deseja realizar esta ação?"
  ],
  "Cancel": [
    null,
    "Cancelar"
  ],
  "Confirm": [
    null,
    "Confirmar"
  ],
  "Could not load view": [
    null,
    "Não foi possível carregar a vista"
  ],
  "Edit": [
    null,
    "Editar"
  ],
  "Failed to load data API information": [
    null,
    "Falha no carregamento da informação dos dados API"
  ],
  "File": [
    null,
    "Ficheiro"
  ],
  "Filters": [
    null,
    "Filtros"
  ],
  "Follow": [
    null,
    "Seguir"
  ],
  "Graph": [
    null,
    "Gráfico"
  ],
  "Grid": [
    null,
    "Grelha"
  ],
  "Hide": [
    null,
    "Ocultar"
  ],
  "Image": [
    null,
    "Imagem"
  ],
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters",
    "",
    "",
    ""
  ],
  "Link": [
    null,
    "Hiperligação"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Link para um URL na internet ( pode também ligar-se com API)"
  ],
  "Loading...": [
    null,
    "A carregar ..."
  ],
  "Map": [
    null,
    "Mapa"
  ],
  "No matches found": [
    null,
    "Não foram encontradas correspondências"
  ],
  "Please Confirm Action": [
    null,
    "Por favor, Confirme a Ação"
  ],
  "Remove": [
    null,
    "Remover"
  ],
  "Resource uploaded": [
    null,
    "Recurso enviado"
  ],
  "Save order": [
    null,
    "Guardar ordenação"
  ],
  "Saving...": [
    null,
    "A guardar ..."
  ],
  "Select a field": [
    null,
    "Selecione um campo"
  ],
  "Show more": [
    null,
    "Mostrar mais"
  ],
  "Start typing…": [
    null,
    "Comece a escrever ..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Existem modificações que não estão a ser guardadas"
  ],
  "There is no API data to load for this resource": [
    null,
    "Não há dados API para carregar neste recurso"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Não é possivel autenticar o envio"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Não foi possivel obter dados a partir do ficheiro enviado"
  ],
  "Unable to upload file": [
    null,
    "Não é possivel enviar o ficheiro"
  ],
  "Unfollow": [
    null,
    "Não Seguir"
  ],
  "Upload": [
    null,
    "Enviar"
  ],
  "Upload a file": [
    null,
    "Enviar um ficheiro"
  ],
  "Upload a file on your computer": [
    null,
    "Envie um ficheiro no seu computador"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Está a enviar um ficheiro. Tem a certeza de que deseja sair e parar o envio?"
  ],
  "error loading view": [
    null,
    "erro a carregar a vista"
  ]
}
